# Generated by Django 4.2.24 on 2025-09-12 08:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("pretix_cashfree", "0001_initial"),
    ]

    operations = [
        migrations.DeleteModel(
            name="PaymentWebhookEvent",
        ),
    ]



from django.urls import include, re_path

from .views import redirect_view, return_view, webhook_view

event_patterns = [
    re_path(
        r"^cashfree/",
        include(
            [
                re_path(r"^return/$", return_view, name="return"),
                re_path(r"^redirect/$", redirect_view, name="redirect"),
                re_path(
                    r"w/(?P<cart_namespace>[a-zA-Z0-9]{16})/return/",
                    return_view,
                    name="return",
                ),
            ]
        ),
    ),
]

urlpatterns = [
    re_path(r"^_cashfree/webhook/$", webhook_view, name="webhook"),
]



from django.utils.translation import gettext_lazy

from . import __version__

try:
    from pretix.base.plugins import PluginConfig
except ImportError:
    raise RuntimeError("Please use pretix 2.7 or above to run this plugin!")


class PluginApp(PluginConfig):
    default = True
    name = "pretix_cashfree"
    verbose_name = "Cashfree"

    class PretixPluginMeta:
        name = gettext_lazy("Cashfree")
        author = "Diptangshu Chakrabarty"
        description = gettext_lazy(
            "This plugin allows you to receive payments via Cashfree"
        )
        visible = True
        version = __version__
        category = "PAYMENT"
        picture = "pretix_cashfree/images/CF_Logo_dark-WhiteBG.svg"
        experimental = True
        compatibility = "pretix>=2.7.0"
        settings_links = []
        navigation_links = []

    def ready(self):
        from . import signals  # NOQA



import logging
from cashfree_pg.api_client import Cashfree, PGWebhookEvent
from cashfree_pg.exceptions import NotFoundException
from cashfree_pg.models.create_order_request import CreateOrderRequest
from cashfree_pg.models.customer_details import CustomerDetails
from cashfree_pg.models.order_create_refund_request import OrderCreateRefundRequest
from cashfree_pg.models.order_entity import OrderEntity
from cashfree_pg.models.order_meta import OrderMeta
from cashfree_pg.models.refund_entity import RefundEntity
from collections import OrderedDict
from datetime import datetime
from decimal import Decimal
from django import forms
from django.contrib import messages
from django.core.cache import caches
from django.http import HttpRequest
from django.template.loader import get_template
from django.urls import reverse
from django.utils.formats import date_format
from django.utils.safestring import mark_safe
from django.utils.translation import gettext_lazy as _
from phonenumber_field.formfields import PhoneNumberField
from phonenumber_field.phonenumber import PhoneNumber
from pretix.base.forms.questions import (
    WrappedPhoneNumberPrefixWidget,
    guess_phone_prefix_from_request,
)
from pretix.base.models import Event, Order, OrderPayment, OrderRefund
from pretix.base.payment import BasePaymentProvider, PaymentException
from pretix.base.settings import SettingsSandbox
from pretix.base.templatetags.rich_text import rich_text
from pretix.helpers.urls import build_absolute_uri as build_global_uri
from pretix.multidomain.urlreverse import build_absolute_uri
from urllib.parse import urlencode

from .constants import (
    DATE_FORMAT,
    PAYMENT_STATUS_SUCCESS,
    REDIRECT_URL_PAYMENT_SESSION_ID,
    RETURN_URL_PARAM,
    SANDBOX_CLIENT_KEY,
    SANDBOX_CLIENT_SECRET,
    SESSION_KEY_ORDER_ID,
    SUPPORTED_COUNTRY_CODES,
    SUPPORTED_CURRENCIES,
    X_API_VERSION,
)
from .models import (
    CashfreePaymentInfo,
    CashfreeRefundInfo,
    PaymentAttempt,
)
from .utils import create_request_id

logger = logging.getLogger("pretix.plugins.cashfree")

try:
    cache = caches["redis"]
except Exception:
    cache = caches["default"]


class CashfreePaymentProvider(BasePaymentProvider):
    identifier = "cashfree"
    verbose_name = "Cashfree"
    public_name = "Cashfree"

    def __init__(self, event: Event):
        super().__init__(event)
        self.settings = SettingsSandbox("payment", "cashfree", event)
        self.init_cashfree()

    @property
    def settings_form_fields(self):
        fields = [
            (
                "client_id",
                forms.CharField(
                    label=_("Client ID"),
                    required=False,
                ),
            ),
            (
                "client_secret",
                forms.CharField(
                    label=_("Client Secret"),
                    required=False,
                    widget=forms.PasswordInput(render_value=True),
                ),
            ),
            (
                "debug_tunnel",
                forms.URLField(
                    label=_("Debug Webhook Tunnel"),
                    required=False,
                    help_text=_(
                        "If provided, this will be used as the base URL for notify webhook"
                    ),
                ),
            ),
        ]

        return OrderedDict(list(super().settings_form_fields.items()) + fields)

    @property
    def payment_phone_session_key(self):
        return f"payment_{self.identifier}_phone"

    def init_cashfree(self):
        """
        Configure Cashfree API credentials
        """
        is_sandbox = self.event.testmode
        Cashfree.XClientId = (
            SANDBOX_CLIENT_KEY if is_sandbox else self.settings.client_id
        )
        Cashfree.XClientSecret = (
            SANDBOX_CLIENT_SECRET if is_sandbox else self.settings.client_secret
        )
        Cashfree.XEnvironment = (
            Cashfree.XSandbox if is_sandbox else Cashfree.XProduction
        )

    def _build_redirect_url(self, request: HttpRequest, session_id: str) -> str:
        base_url = build_absolute_uri(request.event, "plugins:pretix_cashfree:redirect")
        query = urlencode({REDIRECT_URL_PAYMENT_SESSION_ID: session_id})
        return f"{base_url}?{query}"

    def _build_return_url(self, request: HttpRequest, order_id: str) -> str:
        base_url = build_absolute_uri(request.event, "plugins:pretix_cashfree:return")
        query = urlencode({RETURN_URL_PARAM: order_id})
        return f"{base_url}?{query}"

    def _build_notify_url(self, request: HttpRequest) -> str:
        return (
            f"{self.settings.debug_tunnel}{reverse('plugins:pretix_cashfree:webhook')}"
            if self.settings.debug_tunnel
            else build_global_uri("plugins:pretix_cashfree:webhook")
        )

    def _create_cashfree_order_request(
        self, request: HttpRequest, payment: OrderPayment
    ) -> CreateOrderRequest:

        phone: PhoneNumber = request.session[self.payment_phone_session_key]

        customer_phone = str(phone.national_number)
        customer_details = CustomerDetails(
            customer_id=customer_phone,
            customer_email=payment.order.email,
            customer_phone=customer_phone,
        )

        order_id = payment.order.full_code
        return CreateOrderRequest(
            order_id=order_id,
            order_amount=float(payment.amount),
            order_currency=self.event.currency,
            customer_details=customer_details,
            order_meta=OrderMeta(
                return_url=self._build_return_url(request, order_id),
                notify_url=self._build_notify_url(request),
            ),
            order_note=f"{request.event.name} tickets",
        )

    def _create_cashfree_order(self, request, payment: OrderPayment):

        try:
            logger.debug("Creating Cashfree order for : %s", payment)
            create_order_request = self._create_cashfree_order_request(request, payment)

            x_request_id = create_request_id()
            api_response = Cashfree().PGCreateOrder(
                x_api_version=X_API_VERSION,
                create_order_request=create_order_request,
                x_request_id=x_request_id,
            )

            if not api_response or not api_response.data:
                raise Exception("Did not receive order details")

            order_entity = api_response.data
            payment.info_data = self._create_payment_info(x_request_id, order_entity)
            payment.save()
            return self._redirect_cashfree(request, payment, order_entity)

        except Exception as e:
            logger.exception("Error creating Cashfree order: %s", e)
            messages.error(
                request,
                _("There was an error creating the order. Please try again later."),
            )
            raise PaymentException from e

    def _create_payment_info(self, x_request_id: str, order_entity: OrderEntity):
        local_dt = datetime.now()
        updated_at = date_format(local_dt, DATE_FORMAT)
        obj = CashfreePaymentInfo(
            x_request_id=x_request_id,
            order_id=order_entity.order_id,
            cf_order_id=order_entity.cf_order_id,
            order_status=order_entity.order_status,
            order_currency=order_entity.order_currency,
            order_amount=order_entity.order_amount,
            customer_id=order_entity.customer_details.customer_id,
            updated_at=updated_at,
        )
        return obj.dict()

    def _create_refund_info(self, x_request_id: str, refund_entity: RefundEntity):
        local_dt = datetime.now()
        updated_at = date_format(local_dt, DATE_FORMAT)
        date = (
            date_format(refund_entity.processed_at, DATE_FORMAT)
            if refund_entity.processed_at
            else None
        )
        logger.debug("processed at date: %s", date)
        obj = CashfreeRefundInfo(
            x_request_id=x_request_id,
            order_id=refund_entity.order_id,
            refund_id=refund_entity.refund_id,
            cf_refund_id=refund_entity.cf_refund_id,
            cf_payment_id=refund_entity.cf_payment_id,
            refund_type=refund_entity.refund_type,
            refund_status=refund_entity.refund_status,
            refund_amount=refund_entity.refund_amount,
            refund_currency=refund_entity.refund_currency,
            processed_at=refund_entity.processed_at,
            updated_at=updated_at,
        )
        return obj.dict()

    def _redirect_cashfree(
        self, request: HttpRequest, payment: OrderPayment, order_entity: OrderEntity
    ):
        logger.debug("Redirecting to Cashfree for payment: %s", payment)
        request.session[SESSION_KEY_ORDER_ID] = order_entity.order_id
        PaymentAttempt.objects.update_or_create(
            reference=order_entity.order_id, defaults={"payment": payment}
        )
        return self._build_redirect_url(request, order_entity.payment_session_id)

    def _handle_cashfree_order_status(
        self, x_request_id: str, payment: OrderPayment, order_entity: OrderEntity
    ):
        match order_entity.order_status:
            case "ACTIVE":
                logger.debug("Order has no successful transaction yet")
            case "PAID":
                logger.debug("%s is PAID", payment)
                if payment.amount == order_entity.order_amount:
                    payment.confirm()
                else:
                    logger.error(f"{payment} - Amount mismatch with Cashfree")
                    payment.fail()
            case "EXPIRED" | "TERMINATED":
                logger.debug("%s expired or terminated", payment)
                payment.fail()
            case "TERMINATION_REQUESTED":
                logger.debug("%s termination requested", payment)

    def _is_payment_confirmed(self, payment):
        return payment.state == OrderPayment.PAYMENT_STATE_CONFIRMED

    def _verify_webhook_signature(self, signature, timestamp, raw_payload):
        try:
            webhook_response = Cashfree().PGVerifyWebhookSignature(
                signature=signature, timestamp=timestamp, rawBody=raw_payload
            )
        except Exception as e:
            logger.Error("Error: %s", e)
            return None

        return webhook_response

    def _check_webhook_payload(
        self, payment: OrderPayment, webhook_event: PGWebhookEvent
    ):
        # Check idempotency using cf_payment_id
        cf_payment_obj = webhook_event.object["data"]["payment"]
        cf_payment_id = str(cf_payment_obj["cf_payment_id"])
        payment_status = cf_payment_obj["payment_status"]

        key = f"plugins:pretix_cachfree:webhook:payment:{cf_payment_id}"
        if cache.has_key(key=key):
            logger.debug(
                "Webhook payload with cf_payment_id: %s already processed. Skipping...",
                cf_payment_id,
            )
            return True

        cache.set(key=key, value=webhook_event.raw)

        # Verify the payment if Cashfree reports it as successful
        return payment_status == PAYMENT_STATUS_SUCCESS

    def is_allowed(self, request: HttpRequest, total: Decimal = None) -> bool:
        return (
            super().is_allowed(request, total)
            and self.event.currency in SUPPORTED_CURRENCIES
        )

    def payment_is_valid_session(self, request):
        return True

    def execute_payment(self, request: HttpRequest, payment: OrderPayment):
        """
        Redirect to Cashfree to collect payment
        """
        # If already confirmed, go to order details
        if self._is_payment_confirmed(payment):
            return None

        # Check existing payment status
        order_entity = self.verify_payment(payment)
        if order_entity:
            # If confirmed, go to order details. Otherwise redirect to Cashfree with existing payment_session_id
            return (
                None
                if self._is_payment_confirmed(payment)
                else self._redirect_cashfree(request, payment, order_entity)
            )

        # Otherwise create a new Cashfree order and redirect
        return self._create_cashfree_order(request, payment)

    def verify_payment(self, payment: OrderPayment):
        """
        Verify existing Cashfree order status and update payment accordingly
        """

        order_id = payment.order.full_code

        try:
            logger.debug("Fetching Cashfree order for pretix order: %s", order_id)
            x_request_id = create_request_id()
            api_response = Cashfree().PGFetchOrder(
                x_api_version=X_API_VERSION,
                order_id=order_id,
                x_request_id=x_request_id,
            )

            order_entity = api_response.data
            self._handle_cashfree_order_status(x_request_id, payment, order_entity)
            payment.info_data = self._create_payment_info(
                x_request_id=x_request_id, order_entity=order_entity
            )
            payment.save()
            return order_entity

        except NotFoundException:
            logger.debug("Cashfree order not found for payment: %s", payment)
            return None
        except Exception as e:
            logger.e(
                "Error occured while fetching Cashfree order having id: %s", order_id
            )
            raise PaymentException from e

    def handle_webhook(self, raw_payload, signature, timestamp, payment: OrderPayment):
        webhook_event = self._verify_webhook_signature(
            signature=signature, timestamp=timestamp, raw_payload=raw_payload
        )
        if not webhook_event:
            raise Exception(
                "Could not verify webhook signature of payment: %s", payment
            )
        if self._check_webhook_payload(payment=payment, webhook_event=webhook_event):
            self.verify_payment(payment)

    def checkout_prepare(self, request, cart):
        # HACK The following method validats payment form and copies the form values to the session.
        if not super().checkout_prepare(request, cart):
            return False

        phone: PhoneNumber = request.session[self.payment_phone_session_key]

        is_valid_country = phone.country_code in SUPPORTED_COUNTRY_CODES
        is_valid_length = len(str(phone.national_number)) == 10
        valid = is_valid_country and is_valid_length

        if not valid:
            messages.error(
                request,
                _("Please provide a number with +91 extension followed by 10 digits."),
            )
            return False

        return True

    def checkout_confirm_render(
        self, request: HttpRequest, order: Order = None, info_data: dict = None
    ):
        payment_phone = request.session[self.payment_phone_session_key]
        template = get_template("pretix_cashfree/checkout_confirm.html")
        return template.render({"payment_phone": payment_phone})

    def test_mode_message(self):
        return mark_safe(
            _(
                "The Cashfree plugin is operating in test mode. You can use one of <a {args}>many payment modes</a> "
                "to perform a transaction. No money will actually be transferred."
            ).format(
                args='href="https://www.cashfree.com/docs/payments/online/resources/sandbox-environment#sandbox-environment" target="_blank"'
            )
        )

    def payment_form_render(self, request, total, order: Order = None):

        phone = (
            str(order.phone)
            if order
            else (
                next(iter((request.session.get("carts") or {}).values()), {})
                .get("contact_form_data", {})
                .get("phone")
            )
        )
        phone_prefix = guess_phone_prefix_from_request(request, self.event)
        request.session[self.payment_phone_session_key] = (
            PhoneNumber().from_string(phone)
            if phone
            else "+{}.".format(phone_prefix) if phone_prefix else None
        )
        return super().payment_form_render(request, total, order)

    @property
    def payment_form_fields(self):
        logger.debug("payment_form_fields() called")
        fields = [
            (
                "phone",
                PhoneNumberField(
                    label=_("Phone number"),
                    required=True,
                    help_text=rich_text(
                        _("Payment alerts would be sent to this phone number")
                    ),
                    widget=WrappedPhoneNumberPrefixWidget(),
                ),
            )
        ]
        return OrderedDict(fields)

    def payment_control_render(self, request, payment):
        template = get_template("pretix_cashfree/payment_control.html")
        return template.render({"payment_info": payment.info_data})

    def payment_refund_supported(self, payment):
        return True

    def payment_partial_refund_supported(self, payment):
        return False

    def execute_refund(self, refund: OrderRefund):

        order_id = refund.order.full_code

        logger.debug("Creating a refund for order_id: %s", order_id)

        create_refund_request = OrderCreateRefundRequest(
            refund_id=refund.full_id,
            refund_amount=float(refund.amount),
            refund_note=refund.comment,
        )
        x_request_id = create_request_id()

        try:
            api_response = Cashfree().PGOrderCreateRefund(
                x_api_version=X_API_VERSION,
                order_id=order_id,
                order_create_refund_request=create_refund_request,
                x_request_id=x_request_id,
            )

            if not api_response or not api_response.data:
                raise Exception("Did not receive refund details")

            refund.info_data = self._create_refund_info(
                x_request_id=x_request_id, refund_entity=api_response.data
            )
            refund.save()
            refund.done()

        except Exception as e:
            logger.error("Error occurred: %s", e)
            raise PaymentException from e

    def refund_control_render(self, request, refund):
        template = get_template("pretix_cashfree/refund_control.html")
        return template.render({"refund_info": refund.info_data})

    def matching_id(self, payment):
        return CashfreePaymentInfo(**payment.info_data).x_request_id

    def refund_matching_id(self, refund):
        return CashfreeRefundInfo(**refund.info_data).x_request_id



import json
import logging
from django.contrib import messages
from django.http import HttpRequest, HttpResponse
from django.shortcuts import render
from django.utils.translation import gettext_lazy as _
from django.views.decorators.clickjacking import xframe_options_exempt
from django.views.decorators.csrf import csrf_exempt
from django.views.decorators.http import require_POST
from django_scopes import scopes_disabled
from pretix.base.models import Order
from pretix.helpers.http import redirect_to_url
from pretix.multidomain.urlreverse import eventreverse

from .constants import (
    REDIRECT_URL_MODE,
    REDIRECT_URL_PAYMENT_SESSION_ID,
    RETURN_URL_PARAM,
    SESSION_KEY_ORDER_ID,
    WEBHOOK_TYPE_PAYMENT,
)
from .models import PaymentAttempt
from .payment import CashfreePaymentProvider

logger = logging.getLogger("pretix.plugins.cashfree")


@xframe_options_exempt
def redirect_view(request, *args, **kwargs):
    payment_session_id = request.GET.get(REDIRECT_URL_PAYMENT_SESSION_ID, "")

    r = render(
        request,
        "pretix_cashfree/redirect.html",
        {
            REDIRECT_URL_PAYMENT_SESSION_ID: payment_session_id,
            REDIRECT_URL_MODE: (
                "sandbox" if request.event and request.event.testmode else "production"
            ),
        },
    )
    r._csp_ignore = True
    return r


def return_view(request, *args, **kwargs):
    urlkwargs = {}
    if "cart_namespace" in kwargs:
        urlkwargs["cart_namespace"] = kwargs["cart_namespace"]

    order_id = request.GET.get(RETURN_URL_PARAM, "")

    if request.session.get(SESSION_KEY_ORDER_ID):
        cashfree_object = PaymentAttempt.objects.get(
            reference=request.session.get(SESSION_KEY_ORDER_ID)
        )
        payment = cashfree_object.payment
    else:
        payment = None

    if order_id == str(request.session.get(SESSION_KEY_ORDER_ID, None)):
        if payment:
            prov = CashfreePaymentProvider(request.event)

            if not prov.verify_payment(payment):
                logger.error("Failed to process payment with id: %s", order_id)
                messages.error(
                    request,
                    _(
                        "Your payment could not be verified. Please contact support for help."
                    ),
                )
                urlkwargs["step"] = "payment"
                return redirect_to_url(
                    eventreverse(
                        request.event, "presale:event.checkout", kwargs=urlkwargs
                    )
                )
    else:
        messages.error(request, _("Invalid response received from Cashfree"))
        logger.error(
            "The payment_id received from Cashfree does not match the one stored in the session under key '%s'",
            SESSION_KEY_ORDER_ID,
        )
        urlkwargs["step"] = "payment"
        return redirect_to_url(
            eventreverse(request.event, "presale:event.checkout", kwargs=urlkwargs)
        )

    if payment:
        return redirect_to_url(
            eventreverse(
                request.event,
                "presale:event.order",
                kwargs={"order": payment.order.code, "secret": payment.order.secret},
            )
            + ("?paid=yes" if payment.order.status == Order.STATUS_PAID else "")
        )
    else:
        urlkwargs["step"] = "confirm"
        return redirect_to_url(
            eventreverse(request.event, "presale:event.checkout", kwargs=urlkwargs)
        )


@csrf_exempt
@require_POST
@scopes_disabled()
def webhook_view(request: HttpRequest, *args, **kwargs):

    try:
        event_body = request.body.decode("utf-8").strip()
        event_json = json.loads(event_body)
        timestamp = request.headers["x-webhook-timestamp"]
        signature = request.headers["x-webhook-signature"]
    except Exception as e:
        logger.exception("Failed to parse webhook payload: %s", e)
        return HttpResponse(status=400)

    order_id = str(event_json["data"]["order"]["order_id"])
    type = event_json["type"]

    if type != WEBHOOK_TYPE_PAYMENT:
        logger.debug("webhook type: %s, aborting", type)
        return HttpResponse(status=200)

    if not order_id:
        logger.warning("Webhook payloads missing order_id: %s", event_json)
        return HttpResponse(status=400)

    try:
        cashfree_object = PaymentAttempt.objects.get(reference=order_id)
        prov = CashfreePaymentProvider(cashfree_object.payment.order.event)

    except PaymentAttempt.DoesNotExist:
        logger.warning("No ReferencedCashfreeObject found for order_id=%s", order_id)
        return HttpResponse(status=404)
    except Exception as e:
        logger.exception("Error while fetching ReferencedCashfreeObject: %s", e)
        return HttpResponse(status=500)

    try:
        logger.debug("Handling webhook for payment: %s", cashfree_object.payment)
        prov.handle_webhook(
            raw_payload=event_body,
            signature=signature,
            timestamp=timestamp,
            payment=cashfree_object.payment,
        )
    except Exception as e:
        logger.warning("Error occured while processing webhook: %s", e)
        return HttpResponse(status=404)

    return HttpResponse(status=200)



# Register your receivers here
from django.dispatch import receiver
from pretix.base.signals import register_payment_providers


@receiver(register_payment_providers, dispatch_uid="payment_cashfree")
def register_payment_provider(sender, **kwargs):
    from .payment import CashfreePaymentProvider

    return CashfreePaymentProvider



X_API_VERSION = "2025-01-01"
SANDBOX_CLIENT_KEY = "TEST430329ae80e0f32e41a393d78b923034"
SANDBOX_CLIENT_SECRET = "TESTaf195616268bd6202eeb3bf8dc458956e7192a85"
SESSION_KEY_ORDER_ID = "payment_cashfree_pid"
RETURN_URL_PARAM = "order_id"
REDIRECT_URL_PAYMENT_SESSION_ID = "payment_session_id"
REDIRECT_URL_MODE = "mode"
WEBHOOK_TYPE_PAYMENT = "PAYMENT_SUCCESS_WEBHOOK"
PAYMENT_STATUS_SUCCESS = "SUCCESS"
DATE_FORMAT = "SHORT_DATETIME_FORMAT"

SUPPORTED_CURRENCIES = ["INR"]
SUPPORTED_COUNTRY_CODES = [91]



# Generated by Django 4.2.24 on 2025-09-13 04:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("pretix_cashfree", "0002_delete_paymentwebhookevent"),
    ]

    operations = [
        migrations.RenameField(
            model_name="paymentattempt",
            old_name="order_id",
            new_name="reference",
        ),
    ]



from typing import Optional

from django.db import models
from pydantic import BaseModel


class PaymentAttempt(models.Model):
    reference = models.CharField(max_length=190, db_index=True, unique=True)
    payment = models.ForeignKey(
        "pretixbase.OrderPayment",
        null=True,
        blank=True,
        on_delete=models.CASCADE,
        help_text="Latest payment attempt for this order",
    )


class CashfreePaymentInfo(BaseModel):
    x_request_id: str
    order_id: str
    cf_order_id: str
    order_status: str
    order_amount: float
    order_currency: str
    customer_id: str
    updated_at: str


class CashfreeRefundInfo(BaseModel):
    x_request_id: str
    order_id: str
    refund_id: str
    cf_refund_id: str
    cf_payment_id: str
    refund_type: str
    refund_status: str
    refund_amount: float
    refund_currency: str
    processed_at: Optional[str]
    updated_at: str



from setuptools import setup, find_packages


setup(
    name="pretix-cashfree",
    description="Cashfree PG",
    author="Diptangshu Chakrabarty",
    packages=find_packages(),
    include_package_data=True,
    entry_points={
        "pretix.cashfree": ["pretix_cashfree=pretix_cashfree:PretixPluginMeta"]
    },
    install_required=["pretix"],
)



# Generated by Django 4.2.24 on 2025-09-06 10:20

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("pretixbase", "0286_alter_event_currency_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="PaymentWebhookEvent",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False
                    ),
                ),
                (
                    "cf_payment_id",
                    models.CharField(db_index=True, max_length=50, unique=True),
                ),
                ("order_code", models.CharField(max_length=50)),
                ("payment_local_id", models.CharField(max_length=50)),
                ("payment_status", models.CharField(max_length=50)),
                ("payload", models.TextField()),
                ("created_at", models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name="PaymentAttempt",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False
                    ),
                ),
                (
                    "order_id",
                    models.CharField(db_index=True, max_length=190, unique=True),
                ),
                (
                    "payment",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="pretixbase.orderpayment",
                    ),
                ),
            ],
        ),
    ]
